<?php
/**
 *
 * @author Sylver35    http://breizh-portal.com
 * @version $Id$
 * @copyright (c) 2012 sylver35
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */

/**
 * @ignore
 */
define('UMIL_AUTO', true);
define('IN_PHPBB', true);
$phpbb_root_path = (defined('PHPBB_ROOT_PATH')) ? PHPBB_ROOT_PATH : './';
$phpEx = substr(strrchr(__FILE__, '.'), 1);

include($phpbb_root_path . 'common.' . $phpEx);
$user->session_begin();
$auth->acl($user->data);
$user->setup();


if (!file_exists($phpbb_root_path . 'umil/umil_auto.' . $phpEx))
{
	trigger_error('Please download the latest UMIL (Unified MOD Install Library) from: <a href="http://www.phpbb.com/mods/umil/">phpBB.com/mods/umil</a>', E_USER_ERROR);
}

// The name of the mod to be displayed during installation.
$mod_name = 'HIDVIP_INSTALL';

/*
* The name of the config variable which will hold the currently installed version
* UMIL will handle checking, setting, and updating the version itself.
*/
$version_config_name = 'hidvip_version';


// The language file which will be included when installing
$user->add_lang(array('mods/info_acp_abbcodes', 'mods/abbcode', 'posting', 'install'));


/*
* Optionally we may specify our own logo image to show in the upper corner instead of the default logo.
* $phpbb_root_path will get prepended to the path specified
* Image height should be 50px to prevent cut-off or stretching.
*/
//$logo_img = 'styles/prosilver/imageset/site_logo.gif';

// Options to display to the user
if (isset($config['ABBC3_VERSION']))
{
	if (phpbb_version_compare($config['ABBC3_VERSION'], '3.0.12', '>='))
	{
		$abbc3_ok = 'success';
	}
	else
	{
		$abbc3_ok = 'error';
	}
	$result_install = '<br /><br />' .$user->lang['CURRENT_VERSION']. ': ' .$config['ABBC3_VERSION'];
}
else
{
	$abbc3_ok = 'error';
	$result_install = '<br /><br />' .$user->lang['NOT_FOUND'];
}

$options = array(
	'legend2'	=> 'WARNING',
	'welcome'	=> array('lang' => 'HIDVIP_WARNING', 'type' => 'custom', 'function' => 'display_message', 'params' => array('ABBC3_HELP_ALT', $abbc3_ok, $result_install), 'explain' => true),
	'legend3'	=> 'ACP_SUBMIT_CHANGES',
);

/*
* The array of versions and actions within each.
* You do not need to order it a specific way (it will be sorted automatically), however, you must enter every version, even if no actions are done for it.
*
* You must use correct version numbering.  Unless you know exactly what you can use, only use X.X.X (replacing X with an integer).
* The version numbering must otherwise be compatible with the version_compare function - http://php.net/manual/en/function.version-compare.php
*/
$versions = array(
	'1.0.1' => array(
		'permission_add' => array(
			array('u_hidvip', 1),
		),
		'custom' => 'bbcode_handler',
	),
);
$cache->destroy('config');
$cache->destroy('sql', BBCODES_TABLE);

// Include the UMIL Auto file, it handles the rest
include($phpbb_root_path . 'umil/umil_auto.' . $phpEx);

/**
* Display a message with a specified css class
*
* @param string		$lang_string	The language string to display
* @param string		$class			The css class to apply
* @return string					Formated html code
**/
function display_message($lang_string, $class, $option = '')
{
	global $user;

	$lang_string = isset($user->lang[$lang_string]) ? $user->lang[$lang_string] : $lang_string;
	return '<span class="' . $class . '">' . $lang_string . $option . '</span>';
}

/**
* Install, update or remove hidpost BBCode
*
* @param string		$action
* @param string		$version
**/
function bbcode_handler($action)
{
	$message = '';

	switch ($action)
	{
		case 'install':
		case 'update':
			$message .= hidvip_add_bbcodes();
		break;

		case 'uninstall':
			global $umil, $user;
			$umil->table_row_remove('phpbb_bbcodes', array('bbcode_tag' => 'hidvip'));
		break;
	}
	// return a message
	return $message;
}

/**
* Add the bbcode to the bbcodes table
**/
function hidvip_add_bbcodes()
{
	global $db, $template, $user;

	$first_bbcode_id = $max_order = 0;
	$bbcode_added = $message = '';

	// Get last bbcode id - Start
	$sql = 'SELECT MAX(bbcode_id) as max_bbcode_id, MAX(bbcode_order) as max_order
		FROM ' . BBCODES_TABLE;
	$result = $db->sql_query($sql);
	$row = $db->sql_fetchrow($result);
	$db->sql_freeresult($result);

	if ($row)
	{
		$next_bbcode_id = $row['max_bbcode_id'];
		$max_order = $row['max_order'];

		// Make sure it is greater than the core bbcode ids...
		if ($next_bbcode_id <= NUM_CORE_BBCODES)
		{
			$next_bbcode_id = NUM_CORE_BBCODES;
		}
	}
	else
	{
		$next_bbcode_id = NUM_CORE_BBCODES;
	}

	if ($next_bbcode_id > BBCODE_LIMIT)
	{
		trigger_error($user->lang['TOO_MANY_BBCODES']);
	}
	// Get last bbcode id - End
	
	$sql_ary = array(
		'bbcode_id'				=> $next_bbcode_id + 1,
		'bbcode_tag'			=> 'hidvip',
		'bbcode_helpline'		=> 'ABBC3_HIDVIP_TIP',
		'display_on_posting'	=> 1,
		'bbcode_match'			=> '[hidvip]{TEXT}[/hidvip] ',
		'bbcode_tpl'			=> '<div class=\"hiddenbox\"><span class=\"hidden\">{L_MESSAGE_HIDVIP}:</span><div class=\"hiddentext\">{TEXT}</div></div>',
		'first_pass_match'		=> '!\[hidvip\](.*?)\[/hidvip\]!ies',
		'first_pass_replace'	=>  '\'[hidpost=${1}:$uid]\' . str_replace(array("\r\n", \'\"\', \'\\\'\', \'(\', \')\'), array("\n", \'"\', \'&#39;\', \'&#40;\', \'&#41;\'), trim(\'${2}\')) . \'[/hidpost:$uid]\'',
		'first_pass_replace'	=>  '\'[hidvip:$uid]\' .str_replace(array("\r\n", \'\"\', \'\\\'\', \'(\', \')\'), array("\n", \'"\', \'&#39;\', \'&#40;\', \'&#41;\'), trim(\'${1}\')). \'[/hidvip:$uid]\'',
		'second_pass_match'		=> '!\[hidvip:$uid\](.*?)\[/hidvip:$uid\]!ies',
		'second_pass_replace'	=> '$this->hidvip_pass(\'$1\')',
		'display_on_pm'			=> 0,
		'display_on_sig'		=> 0,
		'abbcode'				=> 1,
		'bbcode_image'			=> 'vimeo.gif',
		'bbcode_order'			=> $max_order + 1,
		'bbcode_group'			=> '0',
	);

	// Check if exist
	$sql = 'SELECT bbcode_id
		FROM ' . BBCODES_TABLE . "
		WHERE bbcode_tag = 'hidvip'";
	$result = $db->sql_query($sql);
	$row_exist = $db->sql_fetchfield('bbcode_id');
	$db->sql_freeresult($result);

	if ($row_exist)
	{
		return '';
	}
	else
	{
		$result = $db->sql_query('INSERT INTO ' . BBCODES_TABLE . $db->sql_build_array('INSERT', $sql_ary));

		return $user->lang['INSTALLER_BBCODES_ADD'] . "<p>" . $user->lang['LINE_ADDED'] . ' : ' . $sql_ary['bbcode_tag'] . "</p>";
	}
}

?>